wide_int_type_size_in_bits returns an offset_int (previously an addr_int)
rather than a wide_int, so this patch renames it accordingly.

Tested on powerpc64-linux-gnu and by rerunning the assembly comparison.
OK to install?

Thanks,
Richard


Index: gcc/dwarf2out.c
===================================================================
--- gcc/dwarf2out.c     2013-11-09 09:39:26.725800817 +0000
+++ gcc/dwarf2out.c     2013-11-09 09:39:27.938809015 +0000
@@ -10402,10 +10402,10 @@ simple_type_size_in_bits (const_tree typ
     return TYPE_ALIGN (type);
 }
 
 /* Similarly, but return a wide_int instead of UHWI.  */
 
 static inline offset_int
-wide_int_type_size_in_bits (const_tree type)
+offset_int_type_size_in_bits (const_tree type)
 {
   if (TREE_CODE (type) == ERROR_MARK)
     return BITS_PER_WORD;
@@ -14834,7 +14834,7 @@ field_byte_offset (const_tree decl)
       offset_int type_size_in_bits;
 
       type = field_type (decl);
-      type_size_in_bits = wide_int_type_size_in_bits (type);
+      type_size_in_bits = offset_int_type_size_in_bits (type);
       type_align_in_bits = simple_type_align_in_bits (type);
 
       field_size_tree = DECL_SIZE (decl);
@@ -10402,10 +10402,10 @@ simple_type_size_in_bits (const_tree typ
 }
 
-/* Similarly, but return a wide_int instead of UHWI.  */
+/* Similarly, but return an offset_int instead of UHWI.  */
 
 static inline offset_int

Reply via email to